==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/ca.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activitat",
    "Personal activity feed for %s" : "Canal d'activitat personal per a %s",
    "Your feed URL is invalid" : "La URL del canal no és vàlida",
    "Your settings have been updated." : "La configuració s'ha actualitzat.",
    "This stream will show events like additions, changes & shares" : "Aquest corrent mostrarà esdeveniments afegits, modificats i compartits.",
    "There are no events for this filter" : "No hi ha esdeveniments en est filtre",
    "Activity notification" : "Notificació d'activitat",
    "All Activities" : "Totes les activitats",
    "Activities by you" : "Les teves activitats",
    "Activities by others" : "Activitats dels altres",
    "\"remote user\"" : "\"usuari remot\"",
    "in %s" : "en %s",
    "%s and %s" : "%s i %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s i <strong class=\"tooltip\" title=\"%s\">%n més</strong>","%s i <strong class=\"tooltip\" title=\"%s\">%n més</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s i %n més","%s i %n més"],
    "Hello %s," : "Hola %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Esteu rebent aquest correu perquè en l'última hora han succeït les següents coses a %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Esteu rebent aquest correu perquè en l'últim dia han succeït les següents coses a %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Esteu rebent aquest correu perquè en l'última setmana han succeït les següents coses a %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* i %n més","* i %n més"],
    "Notifications" : "Notificacions",
    "Mail" : "Correu electrónic",
    "Stream" : "Cadena",
    "List your own actions in the stream" : "Enumera les teves pròpies accions en el corrent",
    "Notify about your own actions via email" : "Notifica sobre les teves noves accions via email",
    "You need to set up your email address before you can receive notification emails." : "Heu d'establir l'adreça de correu electrònic abans que pugueu rebre correus de notificació",
    "Send emails:" : "Envia correus electrònics:",
    "Hourly" : "Horàriament",
    "Daily" : "Diari",
    "Weekly" : "Setmanalment",
    "Activity feed" : "Canal d'activitat",
    "Enable RSS feed" : "Activa el canal RSS",
    "No activity yet" : "Cap activitat encara",
    "No more events to load" : "No hi ha més elements a carregar",
    "Files" : "Fitxers"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/activity/l10n/ca.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activitat",
    "Personal activity feed for %s" : "Canal d'activitat personal per a %s",
    "Your feed URL is invalid" : "La URL del canal no és vàlida",
    "Your settings have been updated." : "La configuració s'ha actualitzat.",
    "Mail" : "Correu electrónic",
    "Stream" : "Cadena",
    "Activities" : "Activitats",
    "Error loading activities" : "Error en carregar les activitats",
    "No activities" : "sense activitats",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} i {lastParameter}",
    "in {directory}" : "a {directory}",
    "This stream will show events like additions, changes & shares" : "Aquest corrent mostrarà esdeveniments afegits, modificats i compartits.",
    "There are no events for this filter" : "No hi ha esdeveniments en est filtre",
    "Today" : "Avui",
    "Yesterday" : "Ahir",
    "\"remote user\"" : "\"usuari remot\"",
    "Activity notification" : "Notificació d'activitat",
    "All Activities" : "Totes les activitats",
    "Activities by you" : "Les teves activitats",
    "Activities by others" : "Activitats dels altres",
    "%s and %s" : "%s i %s",
    "Hello %s," : "Hola %s,",
    "You are receiving this email because the following things happened at %s" : "Esteu rebent aquest correu perquè han succeït les següents coses a %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* i %n més","* i %n més"],
    "List your own actions in the stream" : "Enumera les teves pròpies accions en el corrent",
    "Notify about your own actions via email" : "Notifica sobre les teves noves accions via email",
    "You need to set up your email address before you can receive notification emails." : "Heu d'establir l'adreça de correu electrònic abans que pugueu rebre correus de notificació",
    "Send emails:" : "Envia correus electrònics:",
    "Hourly" : "Horàriament",
    "Daily" : "Diari",
    "Weekly" : "Setmanalment",
    "Activity feed" : "Canal d'activitat",
    "Enable RSS feed" : "Activa el canal RSS",
    "No activity yet" : "Cap activitat encara",
    "No more events to load" : "No hi ha més elements a carregar",
    "Files" : "Fitxers"
},
"nplurals=2; plural=(n != 1);");
